@@ -556,7 +556,6 @@ bool do_cmdline_show(string s, int verbose, const shared_ptr<terminal_metrics> &
 {
   cmdline_version_source source;
   string name, sourcestr;
-  string default_release = aptcfg->Find("APT::Default-Release");
   bool has_explicit_source = false;
 
   if(!cmdline_parse_source(s, source, name, sourcestr))
@@ -564,12 +563,6 @@ bool do_cmdline_show(string s, int verbose, const shared_ptr<terminal_metrics> &
 
   has_explicit_source = (source != cmdline_version_cand);
 
-  if(source == cmdline_version_cand && !default_release.empty())
-    {
-      source    = cmdline_version_archive;
-      sourcestr = default_release;
-    }
-
   bool is_pattern = aptitude::matching::is_pattern(name);
   pkgCache::PkgIterator pkg;
 
